OC.L10N.register(
    "logreader",
    {
    "Error parsing log" : "Error al analizar el registro",
    "Copy" : "Copiar",
    "Copy raw" : "Copiar texto",
    "Copy formatted" : "Copiar con formato",
    "No server logs" : "No hay registros del servidor",
    "One or more entries are hidden by the log level filter" : "Una o más entradas están ocultas por el filtro de nivel del registro",
    "Everything is working fine" : "Todo funciona bien",
    "Level" : "Nivel",
    "App" : "Aplicación",
    "Message" : "Mensaje",
    "Time" : "Hora",
    "Log levels" : "Niveles de registro",
    "Log content" : "Contenido del registro",
    "Live update" : "Actualización en directo",
    "Download logs" : "Descargar registros",
    "Logging" : "Registros",
    "Log Reader" : "Lector del registro",
    "A log reader for Nextcloud" : "Un lector del registro para Nextcloud",
    "Log reader for Nextcloud" : "Lector del registro de Nextcloud",
    "Cased by " : "Inspeccionado por"
},
"nplurals=2; plural=(n != 1);");
